--- src/src/pulsecore/core-util.c.orig	2017-01-13 03:02:18.000000000 +0000
+++ src/src/pulsecore/core-util.c	2017-03-06 22:31:51.321911880 +0000
@@ -1812,7 +1812,7 @@
      * users, too. Since we need POSIX locking and UNIX sockets in
      * this directory, we try XDG_RUNTIME_DIR first, and if that isn't
      * set create a directory in $HOME and link it to a random subdir
      * in /tmp, if it was not explicitly configured. */
 
     m = pa_in_system_mode() ? 0755U : 0700U;
 
@@ -1885,7 +1885,7 @@
 
 #ifdef HAVE_SYMLINK
             /* Hmm, so the runtime directory didn't exist yet, so let's
              * create one in /tmp and symlink that to it */
 
             if (make_random_dir_and_link(0700, k) < 0) {
 
@@ -3429,7 +3429,7 @@
         pa_is_path_absolute(t))
         return t;
 
-    return "/tmp";
+    return "@TERMUX_PREFIX@/tmp";
 }
 
 int pa_open_cloexec(const char *fn, int flags, mode_t mode) {
@@ -1812,7 +1812,7 @@
      * this directory, we try XDG_RUNTIME_DIR first, and if that isn't
      * set create a directory in $HOME and link it to a random subdir
-     * in /tmp, if it was not explicitly configured. */
+     * in @TERMUX_PREFIX@/tmp, if it was not explicitly configured. */
 
     m = pa_in_system_mode() ? 0755U : 0700U;
@@ -1885,7 +1885,7 @@
 #ifdef HAVE_SYMLINK
             /* Hmm, so the runtime directory didn't exist yet, so let's
-             * create one in /tmp and symlink that to it */
+             * create one in @TERMUX_PREFIX@/tmp and symlink that to it */
 
             if (make_random_dir_and_link(0700, k) < 0) {